Overview
=========================
galsampler contains a few utility functions such as
:meth:`crossmatch <~galsampler.crossmatch.crossmatch>` and
:meth:`compute_richness <~galsampler.crossmatch.compute_richness>`
that have use cases that are commonly encountered when
generating and analyzing mock galaxy catalogs.
The core functionality of the package is provided by the
:meth:`galsample <~galsampler.galmatch.galsample>` function.
The tutorials below give simple worked examples of these core functions.


.. toctree::
   :maxdepth: 1

   demo_crossmatch.ipynb
   demo_galsampler.ipynb
